@@ -83,7 +83,6 @@ def fetch_data_from_wencai(trade_date=None, fields_query=None,fields_out=None, q
 
 
 if __name__ == "__main__":
-    
     fields = ["收盘价不复权","成交量", "复权因子"]
     fields = ["最高价创250日新高"]
     fields_out = ["股票代码","股票简称",	"开盘价:不复权","最高价:不复权","最低价:不复权", "收盘价:不复权","成交量", "成交额","复权因子", "新股上市日期"]
@@ -91,12 +90,13 @@ if __name__ == "__main__":
     #data_to_excel(fetch_data_from_wencai(trade_date, fields, fields_out),f"stock_daily_{trade_date}")
     #print(fetch_data_from_wencai().columns)
  
-    df = fetch_data_from_wencai(trade_date="2022-07-16",fields_query=["最高价创60日新高"], query_type=QUERY_TYPE.stock)
+    df = fetch_data_from_wencai(trade_date=None,fields_query=["最高价创60日新高"], query_type=QUERY_TYPE.stock)
     print(df)
  
-    print(fetch_data_from_wencai(query_type=QUERY_TYPE().fund))
+    #print(fetch_data_from_wencai(query_type=QUERY_TYPE().fund))
     #print(fetch_data_from_wencai(query_type=QUERY_TYPE().index))
     #print(fetch_data_from_wencai(query_type=QUERY_TYPE().bond))
-    print(fetch_data_from_wencai(query_type=QUERY_TYPE().stock))
+    #print(fetch_data_from_wencai(query_type=QUERY_TYPE().stock))
+   
     
     
