@@ -11,10 +11,9 @@ import pandas as pd
 import requests
 from sqlalchemy import false
 from wencaipy.common.wcParameter import  TRADE_TIMES
+from wencaipy.common.trade_calander import trade_date_sse
 
-rest_days_df = None
-chinese_holidays_range = None
-
+trade_date_cn = trade_date_sse()
 
 def today():
     return datetime.date.today()
@@ -52,51 +51,6 @@ def date2str(cursor_date):
     return cursor_date
 
 
-def _init_chinese_rest_days(headers=None):
-    global rest_days_df, chinese_holidays_range
-    if rest_days_df is None:
-        url = os.getenv("TQ_CHINESE_HOLIDAY_URL", "https://files.shinnytech.com/shinny_chinese_holiday.json")
-        rsp = requests.get(url, timeout=30, headers=headers)
-        chinese_holidays = rsp.json()
-        _first_day = datetime.date(int(chinese_holidays[0].split('-')[0]), 1, 1)  # 首个日期所在年份的第一天
-        _last_day = datetime.date(int(chinese_holidays[-1].split('-')[0]), 12, 31)  # 截止日期所在年份的最后一天
-        chinese_holidays_range = (_first_day, _last_day)
-        rest_days_df = pd.DataFrame(data={'date': pd.Series(pd.to_datetime(chinese_holidays, format='%Y-%m-%d'))})
-        rest_days_df['trading_restdays'] = False  # 节假日为 False
-    return chinese_holidays_range
-
-
-def get_trading_calendar(start_dt=None, end_dt=None, headers=None):
-    """
-    获取一段时间内，每天是否是交易日
-    :return: DataFrame
-        date  trading
-    2019-12-05  True
-    2019-12-06  True
-    2019-12-09  True
-    """
-    _init_chinese_rest_days(headers=headers)
-    df = pd.DataFrame()
-    df['date'] = pd.Series(pd.date_range(start=start_dt, end=end_dt, freq="D"))
-    df['trading'] = df['date'].dt.dayofweek.lt(5)
-    result = pd.merge(rest_days_df, df, sort=True, how="right", on="date")
-    result.fillna(True, inplace=True)
-    df['trading'] = result['trading'] & result['trading_restdays']
-    return df
-
-
-def trade_date_sse(start_dt='1990-01-01', end_dt='2030-12-31'):
-    if not end_dt:
-        end_dt = today()
-    #print(type(end_dt))
-    df = get_trading_calendar(start_dt, end_dt)
-    td = df[df.trading == True]["date"].values
-    td = list(map(lambda x: date2str(x), td))
-    return td
-
-trade_date_cn = trade_date_sse() 
-
-
 def get_last_tradedate():
     _now =  datetime.datetime.now()
     _hour = _now.hour
@@ -152,7 +106,7 @@ def if_trade_datetime(_time=datetime.datetime.now()):
         return False
 
 
-def get_real_trade_date(date, trade_list=trade_date_cn, towards=-1):
+def get_real_trade_date(date=str(today()), trade_list=trade_date_cn, towards=-1):
     """
     explanation:
         获取真实的交易日期
